import 'dart:math';

/// Custom method and propeties for list added with Dart extension
extension ListExtension<T> on List<T> {
  /// Return a list with all indices
  /// </br>
  /// ```dart
  /// final list = ['Jacob', 'Mia', 'Maria'];
  /// print(list.indices); // [0, 1, 2]
  /// ```
  List<int> get indices => List<int>.generate(length, (index) => index);

  /// The number of last index in this list
  /// <br>
  /// ```dart
  /// final list = ['hello', 'test'];
  /// print(list.lastIndex); // 1
  /// ```
  int get lastIndex => max(length - 1, 0);

  /// Create a new instance of list with the same items;
  /// <br>
  /// ```dart
  /// final list = ['hello', 'test'];
  /// final copy = list.copy();
  ///
  /// print(list.hashCode == copy.hashCode); // false
  /// ```
  List<T> copy() => List<T>.from(this);
}
